# workspace-warp-sync
A simple utility to synchronize a local workspace with remote ones

## Commands

* ls 
* add   --src, --dst, --alias
* rm    --src --dst --alias 
* agent --start, --stop, --configure, --reload, --status
* sync  --up/down, --alias

### Development
Configure visual studio code: 
* Install poetry on your system. 
* Install vscode with python extensions
* Run poetry update
* Run poetry shell
* Run code .
* select into vscode the python interpreter.